@@ -50,3 +50,40 @@ QString Settings::volumeDownCommand() const
     QSettings settings("xbmcremote");
     return settings.value("VolumeDownCommand", QString()).toString();
 }
+
+void Settings::setVolumeOnCall(int volume)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("VolumeOnCall", volume);
+}
+
+int Settings::volumeOnCall() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("VolumeOnCall", 10).toInt();
+}
+
+bool Settings::changeVolumeOnCall() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("ChangeVolumeOnCall", true).toBool();
+}
+
+void Settings::setChangeVolumeOnCall(bool changeVolume)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("ChangeVolumeOnCall", changeVolume);
+}
+
+bool Settings::pauseOnCall() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("PauseOnCall", true).toBool();
+}
+
+void Settings::setPauseOnCall(bool pause)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("PauseOnCall", pause);
+}
+
