@@ -1,3 +1,21 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "songs.h"
 #include "audioplayer.h"
 #include "audioplaylist.h"
@@ -6,7 +24,7 @@
 #include "xbmcconnection.h"
 
 Songs::Songs(int artistid, int albumid, XbmcModel *parent):
-    XbmcModel(parent),
+    XbmcLibrary(parent),
     m_artistId(artistid),
     m_albumId(albumid)
 {
@@ -17,13 +35,17 @@ Songs::Songs(int artistid, int albumid, XbmcModel *parent):
     if(albumid != -1) {
       params.insert("albumid", albumid);
     }
-    QVariantList fields;
-    fields.append("artist");
-    fields.append("album");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("artist");
+    properties.append("album");
+    params.insert("properties", properties);
 
     QVariantMap sort;
-    sort.insert("method", "track");
+    if(m_albumId == -1) {
+        sort.insert("method", "label");
+    } else {
+        sort.insert("method", "track");
+    }
     sort.insert("order", "ascending");
     params.insert("sort", sort);
     m_requestId = XbmcConnection::sendCommand("AudioLibrary.GetSongs", params);
@@ -81,11 +103,17 @@ XbmcModel* Songs::enterItem(int index)
 void Songs::playItem(int row)
 {
     AudioPlaylistItem pItem;
-    pItem.setArtistId(m_artistId);
-    pItem.setAlbumId(m_albumId);
+    if(m_artistId == -1 && m_albumId == -1) {
+        pItem.setSongId(index(row, 0, QModelIndex()).data(RoleSongId).toInt());
+    } else if(m_albumId == -1){
+        pItem.setArtistId(m_artistId);
+    } else {
+        pItem.setAlbumId(m_albumId);
+    }
     Xbmc::instance()->audioPlayer()->playlist()->clear();
     Xbmc::instance()->audioPlayer()->playlist()->addItems(pItem);
-    Xbmc::instance()->audioPlayer()->playlist()->playItem(row);
+//    Xbmc::instance()->audioPlayer()->playlist()->playItem(row);
+    Xbmc::instance()->audioPlayer()->playItem(row);
 }
 
 void Songs::addToPlaylist(int row)
